package de.intevation.flys.artifacts.states;

import org.apache.log4j.Logger;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.data.DefaultStateData;
import de.intevation.artifactdatabase.data.StateData;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.utils.FLYSUtils;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class WaterlevelSelectState extends DefaultState {

    private static final Logger logger =
        Logger.getLogger(WaterlevelSelectState.class);

    public static final String SPLIT_CHAR = ";";


    @Override
    protected String getUIProvider() {
        return "wsp_datacage_panel";
    }


    @Override
    public StateData transform(
        FLYSArtifact flys,
        CallContext  cc,
        String       name,
        String       val
    ) {
        if (!isValueValid(val)) {
            logger.error("The given input string is not valid: '" + val + "'");
            return null;
        }

        return new DefaultStateData(name, null, null, strip(val));
    }


    @Override
    public boolean validate(Artifact artifact)
    throws IllegalArgumentException
    {
        FLYSArtifact flys = (FLYSArtifact) artifact;

        StateData data = flys.getData("wsp");

        if (data == null) {
            throw new IllegalArgumentException("WSP is empty");
        }

        return true;
    }


    public static String strip(String value) {
        int start = value.indexOf("[");
        int end   = value.indexOf("]");

        if (start < 0 || end < 0) {
            return value;
        }

        value = value.substring(start+1, end);

        return value;
    }


    /**
     * Validates the given String. A valid string for this state requires the
     * format: "UUID;FACETNAME;FACETINDEX".
     *
     * @param value The string value requires validation.
     *
     * @return true, if the string applies the specified format, otherwise
     * false.
     */
    public static boolean isValueValid(String value) {
        logger.debug("Validate string: '" + value + "'");

        value = strip(value);

        logger.debug("Validate substring: '" + value + "'");

        if (value == null || value.length() == 0) {
            return false;
        }

        String[] parts = value.split(SPLIT_CHAR);

        if (parts == null || parts.length < 3) {
            return false;
        }

        if (parts[0] == null || parts[0].length() == 0) {
            return false;
        }

        if (parts[1] == null || parts[1].length() == 0) {
            return false;
        }

        try {
            Integer.parseInt(parts[2]);
        }
        catch (NumberFormatException nfe) {
            logger.error("Index is not a valid integer!", nfe);
        }

        return true;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
